<script setup>
import { ref, reactive } from "vue";
import tabPower from "./tabs/power.vue";
import tabSystem from "./tabs/system.vue";

const statusList = reactive([
	{ label: '系统状态', value: '充电' },
	{ label: '设备状态', value: '正常' },
	{ label: '电源状态', value: '正常' },
	{ label: '电池状态', value: '正常' },
	{ label: '母线电压', value: 60 },
	{ label: '在线电压', value: 60 },
	{ label: '组端电压', value: 60 },
	{ label: '电池电流', value: 60 },
	{ label: '测试时长', value: 60 },
	{ label: '测试容量', value: 60 },
	{ label: '预估剩余容量', value: 60 },
	{ label: '预估剩余续航', value: 60 },
	{ label: '告警', value: '无' },
	{ label: '更新日期', value: '2022-01-01' },
]);

const tabs = ref([
	{ label: '系统概览', name: 'system' },
	{ label: '电源', name: 'power' },
	{ label: '电压', name: 'vol' },
	{ label: '内阻', name: 'res' },
	{ label: '温度', name: 'temp' },
	{ label: '3D', name: '3d' },
	{ label: '自愈能力', name: 'self' },
	{ label: '管理信息', name: 'manage' },
	{ label: '电源告警参数设置', name: 'powerAlarmSet' },
	{ label: '电池告警参数设置', name: 'battAlarmSet' },
	{ label: '图片', name: 'img' },
	{ label: '历史测试数据', name: 'history' },
	{ label: '历史实时数据', name: 'hisRt' },
]);

const acTab = ref(tabs.value[0].name);

const fullName = ref('湖北省-武汉市-武昌区-武昌机房-电池组1');


function tabClick(item) {
	acTab.value = item.name;
}
</script>

<template>
  <div class="page-contain">
    <div class="page-header">
      <div class="p-title">{{ fullName }}</div>
      <div class="status-bar">
        <div
          :class="['status-item',]"
          v-for="(item, index) in statusList"
          :key="'status_' + index"
        >
          <div class="item-value">{{ item.value }}</div>
          <div class="item-name">{{ item.label }}</div>
        </div>
      </div>
      <div class="p-tabs">
        <div
          :class="['tab-item', {'active': item.name == acTab}]"
          v-for="(item, index) in tabs"
          :key="'tab_' + index"
          @click="tabClick(item)"
        >
          {{ item.label }}
        </div>
      </div>
    </div>
    <div class="page-main">
      <div class="tab-contain" v-if="acTab == 'system'">
        <tab-system></tab-system>
      </div>
      <div class="tab-contain" v-if="acTab == 'power'">
        <tab-power></tab-power>
      </div>
      <div class="tab-contain" v-if="acTab == 'vol'">2</div>
      <div class="tab-contain" v-if="acTab == 'res'">3</div>
      <div class="tab-contain" v-if="acTab == 'temp'">4</div>
      <div class="tab-contain" v-if="acTab == '3d'">5</div>
      <div class="tab-contain" v-if="acTab == 'self'">6</div>
      <div class="tab-contain" v-if="acTab == 'manage'">7</div>
      <div class="tab-contain" v-if="acTab == 'powerAlarmSet'">8</div>
      <div class="tab-contain" v-if="acTab == 'battAlarmSet'">9</div>
      <div class="tab-contain" v-if="acTab == 'img'">10</div>
      <div class="tab-contain" v-if="acTab == 'history'">11</div>
      <div class="tab-contain" v-if="acTab == 'hisRt'">12</div>
    </div>
  </div>
</template>

<style scoped lang="less">
.page-contain {
  display: flex;
  flex-direction: column;

  .page-header {
    // border: 1px solid #0ff;
    background: #071426;

    .p-title {
      font-size: 18px;
      font-weight: 700;
      color: #50c7f1;
      height: 42px;
      display: flex;
      justify-content: center;
      align-items: center;
      border-bottom: 1px solid #497AAB;
    }

    .status-bar {
      height: 72px;
      display: flex;
      flex-direction: row;

      .status-item {
        flex: 1;
        font-size: 14px;
        font-weight: 700;
        color: #50c7f1;
        // border: 1px solid #0F6B79;
        border-radius: 6px;
        margin: 4px 6px;
        display: flex;
        flex-direction: column;
        justify-content: center;
        align-items: center;
        box-shadow: inset 0 0 30px -10px #0F6B79;
        background: radial-gradient(circle at -10% center, #1F6571 5%, transparent 20%) no-repeat,
            radial-gradient(circle at 110% center, #1F6571 5%, transparent 20%) no-repeat,
            radial-gradient(circle at center -72%, #1F6571 12%, transparent 50%) no-repeat,
            radial-gradient(circle at center 138%, #1F6571 12%, transparent 50%) no-repeat;

        .item-value {
          margin-bottom: 6px;
          color: #ff0;
          font-size: 20px;
        }

        .item-name {
          color: #6DCCE6;
        }
      }
    }

    .p-tabs {
      display: flex;
      flex-direction: row;
      height: 46px;
      border: 1px solid #426EA0;
      padding: 4px;

      .tab-item {
        font-size: 14px;
        font-weight: 700;
        flex: 1;
        display: flex;
        justify-content: center;
        align-items: center;
        margin-left: 2px;
        margin-right: 2px;
        background: #073451;
        cursor: pointer;

        &.active {
          background: #47CAFE;
          color: #03216e;
        }
      }
    }
  }

  .page-main {
    flex: 1;

    .tab-contain {
      height: 100%;
    }

  }
}
</style>
